const { join } = require('path')
const fs = require('fs-extra')
const inquirer = require('inquirer')
const { info, success, error, getSpinner, installDep } = require('../utils/tools')
const { shell } = require('execa')
const { setPkgJson } = require('../utils/zc')

module.exports = async function() {
  let projectName = process.argv[3] || ''
  if (!projectName.trim()) {
    const { _projectName } = await inquirer.prompt([
      {
        type: 'input',
        message: '你想创建的工程名称：',
        name: '_projectName',
        validate(val) {
          return val.trim() ? true : '\n请输入工程名称'
        }
      }
    ])
    projectName = _projectName
  }
  await createProject(projectName)
}
async function createProject(projectName) {
  const cwd = process.cwd()
  const projectPath = join(cwd, projectName)
  let generateSpinner = getSpinner('正在创建... ')
  try {
    info(`\n 开始创建 '${projectName}' 工程,请稍等...`)
    generateSpinner.start()
    await shell(`git clone -b master https://github.com/ZC828/zc-vue-project-boilerplate.git ${projectName}`)
    await fs.remove(join(projectPath, '.git'))
    setPkgJson(projectName)
    await installDep(projectPath)
    generateSpinner.stop()
    success('\n √ 创建成功,执行以下命令,启动项目')
    success(`\n $ cd ${projectName}`)
    success('\n $ npm start or yarn start')
  } catch (e) {
    generateSpinner.stop()
    error(e)
  }
}
