const fs = require('fs-extra')
const { join } = require('path')
const { shell } = require('execa')
const { installDep, getSpinner, warning, success, error } = require('../utils/tools')
const { __pkgJson } = require('../utils/paths')
const { zcServerName, zcCliName } = require('../utils/constant')
const { shouldUpdateZcServer, isZcProject } = require('../utils/zc')

module.exports = async function() {
  if (!isZcProject()) {
    return warning(`\n 此项目不是一个 ${zcCliName} 创建的项目，无法使用该命令`)
  }
  if (!shouldUpdateZcServer()) {
    return warning('\n项目配置已经是最新的了，不需要升级了')
  }
  const updateSpinner = getSpinner('updating...')
  updateSpinner.start()
  try {
    const { stdout } = await shell(`npm view ${zcServerName} version`)
    const pkgJson = require(__pkgJson)
    if (pkgJson.dependencies && pkgJson.dependencies[zcServerName]) {
      delete pkgJson.dependencies[zcServerName]
    }
    if (!pkgJson.devDependencies) {
      pkgJson.devDependencies = {}
    }
    pkgJson.devDependencies[zcServerName] = stdout
    await fs.writeFile(__pkgJson, JSON.stringify(pkgJson, null, 2))
    await installDep()
    updateSpinner.stop()
    success('\n√更新成功')
    const updateLogPath = join(process.cwd(), `node_modules/${zcServerName}/update-log`)
    if (fs.pathExistsSync(updateLogPath)) {
      const res = fs.readFileSync(updateLogPath, 'utf8')
      success(res)
    }
  } catch (e) {
    error(e)
  }
}
