const fs = require('fs-extra')
const { join } = require('path')
const { shellSync, shell } = require('execa')
const { __nodeModules, __zcConfig, __pkgJson, __src, __page } = require('../paths')
const { zcServerName } = require('../constant')

function isZcProject() {
  const { dependencies = {}, devDependencies = {} } = require(__pkgJson)
  return (
    fs.pathExistsSync(__zcConfig) &&
    fs.pathExistsSync(__src) &&
    fs.pathExistsSync(__page) &&
    (dependencies[zcServerName] || devDependencies[zcServerName])
  )
}
// 设置zc.config.js中的page字段
function setPageNameOfZcConfig(name) {
  if (!fs.pathExistsSync(__zcConfig)) {
    fs.writeFileSync(
      __zcConfig,
      `
module.exports = {
  page: ['${name}']
}
`.trim()
    )
  } else {
    const res = fs.readFileSync(__zcConfig, 'utf8')
    fs.writeFileSync(__zcConfig, res.replace(/page\s*:\s*((\[(.+?)\])|('(.+?)')|("(.+?)"))\s*,?/g, `page:['${name}'],`))
  }
}

function getZcServerVersion() {
  return shellSync(`npm view ${zcServerName} version`).stdout
}
function setPkgJson(projectName) {
  const latestVer = getZcServerVersion()
  const { stdout } = shellSync('git config user.name')
  const packagePath = join(process.cwd(), projectName, 'package.json')
  const pkgJson = require(packagePath)
  pkgJson.name = projectName
  pkgJson.author = stdout
  pkgJson.devDependencies[zcServerName] = latestVer
  if (pkgJson.dependencies && pkgJson.dependencies[zcServerName]) {
    delete pkgJson.dependencies[zcServerName]
  }
  fs.writeFileSync(packagePath, JSON.stringify(pkgJson, null, 2))
}
function shouldUpdateZcServer() {
  const currentVer = require(join(__nodeModules, `${zcServerName}/package.json`)).version
  try {
    const latestVer = getZcServerVersion()
    if (latestVer !== currentVer) {
      return {
        currentVer,
        latestVer
      }
    }
    return false
  } catch (e) {
    return false
  }
}
function getZcConfig() {
  return Object.assign(resConfig, require(__zcConfig))
}
async function getZcServerDep() {
  let { stdout } = await shell(`npm view ${zcServerName} dependencies`)
  stdout = stdout.trim()
  return stdout
    .substring(1, stdout.length - 1)
    .split(',')
    .map(item => {
      let key = item.substring(0, item.indexOf(':')).trim()
      if (key.charAt(0) === "'" || key.charAt(0) === '"') {
        key = key.substring(1, key.length - 1)
      }
      return key
    })
}
module.exports = {
  isZcProject,
  setPageNameOfZcConfig,
  getZcServerVersion,
  setPkgJson,
  shouldUpdateZcServer,
  getZcConfig,
  getZcServerDep
}
